@@ -260,9 +260,9 @@ class BVTCases(Cases):
                         story_id=stories_map.get(self.case_ws[story_cell].value),
                         iteration_id=self.iteration_meta_info['iteration_id'],
                         description=template.render(
-                            precondition=self.case_ws[precondition_cell].value,
-                            case_steps=self.case_ws[steps_cell].value,
-                            expected=self.case_ws[expected_cell].value
+                            precondition=self.case_ws[precondition_cell].value or '',
+                            case_steps=self.case_ws[steps_cell].value or '',
+                            expected=self.case_ws[expected_cell].value or ''
                         )
                     )
                     if task_id:
